@@ -37,7 +37,6 @@
 #include "core/ControlManager.h"
 #include "core/mixer.h"
 #include "gui/guiprofile.h"
-#include "gui/volumeslider.h"
 #include "gui/viewbase.h"
 #include "gui/verticaltext.h"
 #include "gui/toggletoolbutton.h"
@@ -1124,7 +1123,7 @@ void MDWSlider::showMoveMenu()
     m_moveMenu->addSeparator();
 
     // Device actions
-    for (const shared_ptr<MixDevice> md : *ms)
+    for (const shared_ptr<MixDevice> &md : *ms)
     {
 	act = new QAction(QIcon::fromTheme(md->iconName()), md->readableName(), m_moveMenu);
 	act->setData(md->id());
